/*
 * The contents of this file are subject to the AOLserver Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://aolserver.com/.
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See
 * the License for the specific language governing rights and limitations
 * under the License.
 *
 * The Original Code is AOLserver Code and related documentation
 * distributed by AOL.
 * 
 * The Initial Developer of the Original Code is America Online,
 * Inc. Portions created by AOL are Copyright (C) 1999 America Online,
 * Inc. All Rights Reserved.
 *
 * Alternatively, the contents of this file may be used under the terms
 * of the GNU General Public License (the "GPL"), in which case the
 * provisions of GPL are applicable instead of those above.  If you wish
 * to allow use of your version of this file only under the terms of the
 * GPL and not to allow others to use your version of this file under the
 * License, indicate your decision by deleting the provisions above and
 * replace them with the notice and other provisions required by the GPL.
 * If you do not delete the provisions above, a recipient may use your
 * version of this file under either the License or the GPL.
 */


/* 
 * urlencode.c --
 *
 *	Encode and decode URLs, as described in RFC 1738.
 */

static const char *RCSID = "@(#) $Header: /cvsroot/aolserver/aolserver/nsd/urlencode.c,v 1.3 2000/08/25 13:49:57 jgdavidson Exp $, compiled: " __DATE__ " " __TIME__;

#include "nsd.h"


/*
 *----------------------------------------------------------------------
 *
 * NsTclUrlEncodeCmd --
 *
 *	Implments ns_urlencode. 
 *
 * Results:
 *	Tcl result. 
 *
 * Side effects:
 *	See docs. 
 *
 *----------------------------------------------------------------------
 */

int
NsTclUrlEncodeCmd(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
{
    Ns_DString  ds;
    char       *data;
    char       *charset;

    if (argc == 2) {
	charset = NULL;
	data = argv[1];
    } else if (argc == 4 && strcmp(argv[1], "-charset") == 0) {
	charset = argv[2];
	data = argv[3];
    } else {
        Tcl_AppendResult(interp, "bad usage: should be \"",
                         argv[0], " ?-charset charset? data\"", NULL);
        return TCL_ERROR;
    }

    Ns_DStringInit(&ds);

    Ns_EncodeUrlCharset(&ds, data, charset);

    Tcl_SetResult(interp, Ns_DStringExport(&ds), (Tcl_FreeProc *) ns_free);
    
    return TCL_OK;
}


/*
 *----------------------------------------------------------------------
 *
 * NsTclUrlDecodeCmd --
 *
 *	Implements ns_urldecode. 
 *
 * Results:
 *	Tcl result. 
 *
 * Side effects:
 *	See docs. 
 *
 *----------------------------------------------------------------------
 */

int
NsTclUrlDecodeCmd(ClientData dummy, Tcl_Interp *interp, int argc, char **argv)
{
    Ns_DString  ds;
    char       *charset;
    char       *data;

    if (argc == 2) {
	charset = NULL;
	data = argv[1];
    } else if (argc == 4 && strcmp(argv[1], "-charset") == 0) {
	charset = argv[2];
	data = argv[3];
    } else {
        Tcl_AppendResult(interp, "bad usage: should be \"",
                         argv[0], " ?-charset charset? data\"", NULL);
        return TCL_ERROR;
    }

    Ns_DStringInit(&ds);
    if (Ns_DecodeUrlCharset(&ds, data, charset) == NULL) {
        Ns_DStringFree(&ds);
    }
    Tcl_SetResult(interp, Ns_DStringExport(&ds), (Tcl_FreeProc *) ns_free);
    
    return TCL_OK;
}

