# $Id: aolserver-2-emulation.tcl,v 1.1.1.1 2000/05/19 23:47:09 jsalz Exp $
# File:        aolserver-2-emulation.tcl
# Author:      Jon Salz <jsalz@mit.edu>, from code by markd
# Date:        19 May 2000
# Description: Contains procedures specific to AOLserver 3, recreating
#              functionality dropped from AOLserver 2.

# -1 = Not there or value was ""
#  0 = NULL, set value to NULL.
#  1 = Got value, set value to it.

proc ns_dbformvalue {formdata column type valuebyref} {

    upvar $valuebyref value

    if {[ns_set get $formdata ColValue.[ns_urlencode $column].NULL] == "t"} {
	set value ""
	return 0
    }

    set value [ns_set get $formdata ColValue.[ns_urlencode $column]]

    if [string match $value ""] {
        switch $type {
	    
	    date      {
		set value [ns_buildsqldate \
			[ns_set get $formdata ColValue.[ns_urlencode $column].month] \
			[ns_set get $formdata ColValue.[ns_urlencode $column].day] \
			[ns_set get $formdata ColValue.[ns_urlencode $column].year]]
	    }
	    
	    time      {
		set value [ns_buildsqltime \
			[ns_set get $formdata ColValue.[ns_urlencode $column].time] \
			[ns_set get $formdata ColValue.[ns_urlencode $column].ampm]]
	    }
	    
            datetime  -
	    timestamp {
		set value [ns_buildsqltimestamp \
			[ns_set get $formdata ColValue.[ns_urlencode $column].month] \
			[ns_set get $formdata ColValue.[ns_urlencode $column].day] \
			[ns_set get $formdata ColValue.[ns_urlencode $column].year] \
			[ns_set get $formdata ColValue.[ns_urlencode $column].time] \
			[ns_set get $formdata ColValue.[ns_urlencode $column].ampm]]
	    }
	    
	    default {
	    }
	}
    }
    if [string match $value ""] {
	return -1
    } else {
	return 1
    }
}

proc ns_dbformvalueput {htmlform column type value} {

    switch $type {

	date {
	    set retval [ns_formvalueput $htmlform ColValue.[ns_urlencode $column].NULL f]
	    set retval [ns_formvalueput $retval ColValue.[ns_urlencode $column].month \
		    [ns_parsesqldate month $value]]
	    set retval [ns_formvalueput $retval ColValue.[ns_urlencode $column].day \
		    [ns_parsesqldate day $value]]
	    set retval [ns_formvalueput $retval ColValue.[ns_urlencode $column].year \
		    [ns_parsesqldate year $value]]
	}

	time {
	    set retval [ns_formvalueput $htmlform ColValue.[ns_urlencode $column].NULL f]
	    set retval [ns_formvalueput $retval ColValue.[ns_urlencode $column].time \
		    [ns_parsesqltime time $value]]
	    set retval [ns_formvalueput $retval ColValue.[ns_urlencode $column].ampm \
		    [ns_parsesqltime ampm $value]]

	}

        datetime  -
	timestamp {
	    set retval [ns_formvalueput $htmlform ColValue.[ns_urlencode $column].NULL f]
	    set retval [ns_formvalueput $retval ColValue.[ns_urlencode $column].month \
		    [ns_parsesqltimestamp month $value]]
	    set retval [ns_formvalueput $retval ColValue.[ns_urlencode $column].day \
		    [ns_parsesqltimestamp day $value]]
	    set retval [ns_formvalueput $retval ColValue.[ns_urlencode $column].year \
		    [ns_parsesqltimestamp year $value]]
	    set retval [ns_formvalueput $retval ColValue.[ns_urlencode $column].time \
		    [ns_parsesqltimestamp time $value]]
	    set retval [ns_formvalueput $retval ColValue.[ns_urlencode $column].ampm \
		    [ns_parsesqltimestamp ampm $value]]
	    
	}

	default {

	    set retval [ns_formvalueput $htmlform ColValue.[ns_urlencode $column] $value]
	}
    }
    return $retval
}

proc _ns_updatebutton {db table var} {
    upvar $var updatebutton

    if ![info exists updatebutton] {
	set updatebutton ""
    }
    if [string match "" $updatebutton] {
	set updatebutton [ns_table value $db $table update_button_label]
    }
    if [string match "" $updatebutton] {
	set updatebutton "Update Record"
    }
}

proc ns_findrowbyid {db table rowidset} {

    set sql "select * from [ns_dbquotename $table] where"
    for {set i 0} {$i < [ns_set size $rowidset]} {incr i} {
	if {$i != 0} {
	    append sql " and"
	}
	set column [ns_urldecode [ns_set key $rowidset $i]]
	set value [ns_set value $rowidset $i]
	set type [ns_column type $db $table $column]
	append sql " [ns_dbquotename $column] = [ns_dbquotevalue $value $type]"
    }
    if [catch {
	set row [ns_db 1row $db $sql]
    } errMsg] {
	ns_db setexception $db NSINT "Could not find row"
	error $errMsg
    }
    return $row
}

proc _http_read args {
    eval _ns_http_read $args
}
proc _http_puts args {
    eval _ns_http_puts $args
}
proc _http_gets args {
    eval _ns_http_gets $args
}

# tcl page support

proc ns_putscript {conn ignored} {
	ns_returnbadrequest $conn "Cannot PUT a script file"
}

ns_share NS
set NS(months) [list January February March April May June \
        July August September October November December]

proc _ns_dateentrywidget {column} {
    ns_share NS

    set output "<SELECT name=ColValue.[ns_urlencode $column].month>\n"
    for {set i 0} {$i < 12} {incr i} {
	append output "<OPTION> [lindex $NS(months) $i]\n"
    }

    append output \
"</SELECT>&nbsp;<INPUT NAME=ColValue.[ns_urlencode $column].day\
TYPE=text SIZE=3 MAXLENGTH=2>&nbsp;<INPUT NAME=ColValue.[ns_urlencode $column].year\
TYPE=text SIZE=5 MAXLENGTH=4>"

    return [ns_dbformvalueput $output $column date [lindex [split [ns_localsqltimestamp] " "] 0]]
}

proc _ns_timeentrywidget {column} {
    
    set output "<INPUT NAME=ColValue.[ns_urlencode $column].time TYPE=text SIZE=9>&nbsp;<SELECT NAME=ColValue.[ns_urlencode $column].ampm>
<OPTION> AM
<OPTION> PM
</SELECT>"

    return [ns_dbformvalueput $output $column time [lindex [split [ns_localsqltimestamp] " "] 1]]
}
