#!/bin/bash -e

if [ "$ORACLE_HOME" = "" ]; then
    echo 1>&2 "ORACLE_HOME must be set."
    exit 1
fi

umask 002

instbase=aol33
tarball="$instbase-bin-$(uname).tar.gz"
export INST="$PWD/../$instbase"
[ -d "$INST" ] || mkdir "$INST"

for module in aolserver nscache nsrewrite nssha1; do
    echo "Running make in ../$module; output in $module.log"
    (
	cd "../$module" && make INST="$INST" && make install INST="$INST"
    ) > "$module.log" 2>&1
done

cat > getversion.c <<EOF
#include <stdio.h>
#include "../oracle-driver/version.h"
int main(int argc, char **argv) {
    puts(ORA8_DRIVER_VERSION);
    return 0;
}
EOF
gcc -o getversion getversion.c
driver_version="$(./getversion)"
rm -f getversion getversion.c

oracle_versions="$(cd $ORACLE_HOME/.. && ls -d 8*)"
for ov in $oracle_versions; do
    echo "Building Oracle driver for Oracle $ov; output in ora$ov.log"
    (
	cd ../oracle-driver && make INST="$INST" ORACLE_HOME="$ORACLE_HOME/../$ov" clean && make INST="$INST" ORACLE_HOME="$ORACLE_HOME/../$ov"
    ) > "ora$ov.log" 2>&1
    mv ../oracle-driver/ora8.so "$INST/bin/ora$ov-$driver_version.so"
    ln -s "ora$ov-$driver_version.so" "$INST/bin/ora$ov.so"
    mv ../oracle-driver/ora8cass.so "$INST/bin/ora${ov}cass-$driver_version.so"
    ln -s "ora${ov}cass-$driver_version.so" "$INST/bin/ora${ov}cass.so"
done

echo "Fixing up installation tree..."

rm -f "$INST/bin/nsd76" "$INST/bin/nsd"
ln -s nsd8x "$INST/bin/nsd"

cp ../aolserver/encoding-doc.html "$INST"
cp ../aolserver/DISTRIBUTION* "$INST"
cp CONTENTS "$INST"

cp files/nsd-oracle "$INST/bin"
chmod 775 "$INST/bin/nsd-oracle"

cp files/install-latest-aolserver "$INST/bin"
chmod 775 "$INST/bin/install-latest-aolserver"

echo "Attempting to change ownership of installation tree to nsadmin..."
set +e
sudo chown -R nsadmin "$INST"
set -e

echo "Creating $tarball ..."
( cd "$INST/.." && tar cf - "$instbase" ) | gzip -9 > "$tarball"

echo "Done."
exit 0
